
#ifndef KMM_WIDGETS_EXPORT_H
#define KMM_WIDGETS_EXPORT_H

#ifdef KMM_WIDGETS_STATIC_DEFINE
#  define KMM_WIDGETS_EXPORT
#  define KMM_WIDGETS_NO_EXPORT
#else
#  ifndef KMM_WIDGETS_EXPORT
#    ifdef MAKE_KMM_WIDGETS_LIB
        /* We are building this library */
#      define KMM_WIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KMM_WIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KMM_WIDGETS_NO_EXPORT
#    define KMM_WIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KMM_WIDGETS_DEPRECATED
#  define KMM_WIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KMM_WIDGETS_DEPRECATED_EXPORT
#  define KMM_WIDGETS_DEPRECATED_EXPORT KMM_WIDGETS_EXPORT KMM_WIDGETS_DEPRECATED
#endif

#ifndef KMM_WIDGETS_DEPRECATED_NO_EXPORT
#  define KMM_WIDGETS_DEPRECATED_NO_EXPORT KMM_WIDGETS_NO_EXPORT KMM_WIDGETS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KMM_WIDGETS_NO_DEPRECATED
#    define KMM_WIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* KMM_WIDGETS_EXPORT_H */
